Use the 'ecc-engine' standard property instead of the custom
'ingenic,bch-controller' custom property, which is now deprecated.

Signed-off-by: Paul Cercueil <p...@crapouillou.net>
---

Notes:
    v5: New patch

 drivers/mtd/nand/raw/ingenic/ingenic_ecc.c | 13 ++++++++++---
 1 file changed, 10 insertions(+), 3 deletions(-)

diff --git a/drivers/mtd/nand/raw/ingenic/ingenic_ecc.c 
b/drivers/mtd/nand/raw/ingenic/ingenic_ecc.c
index d7f3a8c3abea..30436ca6628a 100644
--- a/drivers/mtd/nand/raw/ingenic/ingenic_ecc.c
+++ b/drivers/mtd/nand/raw/ingenic/ingenic_ecc.c
@@ -82,9 +82,9 @@ static struct ingenic_ecc *ingenic_ecc_get(struct device_node 
*np)
 
 /**
  * of_ingenic_ecc_get() - get the ECC controller from a DT node
  * @of_node: the node that contains a bch-controller property.
  *
  * Get the bch-controller property from the given device tree
  * node and pass it to ingenic_ecc_get to do the work.
  *
  * Return: a pointer to ingenic_ecc, errors are encoded into the pointer.
@@ -95,7 +95,14 @@ struct ingenic_ecc *of_ingenic_ecc_get(struct device_node 
*of_node)
        struct ingenic_ecc *ecc = NULL;
        struct device_node *np;
 
-       np = of_parse_phandle(of_node, "ingenic,bch-controller", 0);
+       np = of_parse_phandle(of_node, "ecc-engine", 0);
+
+       /*
+        * If the ecc-engine property is not found, check for the deprecated
+        * ingenic,bch-controller property
+        */
+       if (!np)
+               np = of_parse_phandle(of_node, "ingenic,bch-controller", 0);
 
        if (np) {
                ecc = ingenic_ecc_get(np);
@@ -82,9 +82,9 @@ static struct ingenic_ecc *ingenic_ecc_get(struct device_node 
 /**
  * of_ingenic_ecc_get() - get the ECC controller from a DT node
- * @of_node: the node that contains a bch-controller property.
+ * @of_node: the node that contains a ecc-engine property.
  *
@@ -82,9 +82,9 @@ static struct ingenic_ecc *ingenic_ecc_get(struct device_node 
  *
- * Get the bch-controller property from the given device tree
+ * Get the ecc-engine property from the given device tree
  * node and pass it to ingenic_ecc_get to do the work.
  *
-- 
2.11.0

Reply via email to